==> scraping-1.0.0-sources.jar: com/tenqube/visual_scraper/data/ParsingRuleData.java <==
package com.tenqube.visual_scraper.data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Map;

/**
 * Created by tenqube on 2018. 5. 18..
 */

public class ParsingRuleData implements Serializable {

    public String name;
    public String displayName;
    //login
    public String loginUrl;
    public int isApiLogin;
    public String webViewScriptCode;
    public String id;
    public String pw;
    public ArrayList<String> validCookieKey;
    public Map<String, String> loginParams;
    public ArrayList<String> exceptScriptCode;

    //purchase
    public String purchaseUrl;
    public String purchaseDivCss;
    public int purchaseMethodType;
    public Map<String, String> purchaseParams;

    @Override
    public String toString() {
        return "ParsingRuleData{" +
                "name='" + name + '\'' +
                ", displayName='" + displayName + '\'' +
                ", loginUrl='" + loginUrl + '\'' +
                ", isApiLogin=" + isApiLogin +
                ", webViewScriptCode='" + webViewScriptCode + '\'' +
                ", id='" + id + '\'' +
                ", pw='" + pw + '\'' +
                ", validCookieKey=" + validCookieKey +
                ", loginParams=" + loginParams +
                ", exceptScriptCode=" + exceptScriptCode +
                ", purchaseUrl='" + purchaseUrl + '\'' +
                ", purchaseDivCss='" + purchaseDivCss + '\'' +
                ", purchaseMethodType=" + purchaseMethodType +
                ", purchaseParams=" + purchaseParams +
                '}';
    }


//    public String domain;
//    public String purchasePagetableRowCss;
//    public String orderNumAttrName;
//    public String detailOrdernumDivCss;
//    public String detailDomainUrl;
//    public int detailMethodType;
//    public HashMap<String,String> detailParams;
//    public String orderParamKey;
//    public String regEx;
//    public String detailDivCss;
//    public String detailPurchaseUrl;

//    @Override
//    public String toString() {
//        return "ParsingRuleData{" +
//                "mallId=" + mallId +
//                ", loginUrl='" + loginUrl + '\'' +
//                ", purchaseUrl='" + purchaseUrl + '\'' +
//                ", domain='" + domain + '\'' +
//                ", detailPurchaseUrl='" + detailPurchaseUrl + '\'' +
//                ", isApiLogin=" + isApiLogin +
//                ", webViewScriptCode='" + webViewScriptCode + '\'' +
//                ", id='" + id + '\'' +
//                ", pw='" + pw + '\'' +
//                ", loginParams=" + loginParams +
//                ", validCookieKey='" + validCookieKey + '\'' +
//                ", purchaseDivCss='" + purchaseDivCss + '\'' +
//                ", purchasePagetableRowCss='" + purchasePagetableRowCss + '\'' +
//                ", detailDivCss='" + detailDivCss + '\'' +
//                ", detailOrdernumDivCss='" + detailOrdernumDivCss + '\'' +
//                ", detailDomainUrl='" + detailDomainUrl + '\'' +
//                '}';
//    }
}

==> scraping-1.0.3-sources.jar: com/tenqube/visual_scraper/data/ParsingRuleData.java <==
package com.tenqube.visual_scraper.data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Map;

/**
 * Created by tenqube on 2018. 5. 18..
 */

public class ParsingRuleData implements Serializable {

    public String name;
    public String displayName;
    //login
    public String loginUrl;
    public int isApiLogin;
    public String logoUrl;
    public String webViewScriptCode;
    public String id;
    public String pw;
    public ArrayList<String> validCookieKey;
    public Map<String, String> loginParams;
    public ArrayList<String> exceptScriptCode;

    //purchase
    public String purchaseUrl;
    public String purchaseDivCss;
    public int purchaseMethodType;
    public Map<String, String> purchaseParams;


    //detail
    public String detailParams;
    public int detailMetodtype;
    public String detailDomainUrl;
    public String detailPageDivCss;


    @Override
    public String toString() {
        return "ParsingRuleData{" +
                "name='" + name + '\'' +
                ", displayName='" + displayName + '\'' +
                ", loginUrl='" + loginUrl + '\'' +
                ", isApiLogin=" + isApiLogin +
                ", logoUrl='" + logoUrl + '\'' +
                ", webViewScriptCode='" + webViewScriptCode + '\'' +
                ", id='" + id + '\'' +
                ", pw='" + pw + '\'' +
                ", validCookieKey=" + validCookieKey +
                ", loginParams=" + loginParams +
                ", exceptScriptCode=" + exceptScriptCode +
                ", purchaseUrl='" + purchaseUrl + '\'' +
                ", purchaseDivCss='" + purchaseDivCss + '\'' +
                ", purchaseMethodType=" + purchaseMethodType +
                ", purchaseParams=" + purchaseParams +
                ", detailParams='" + detailParams + '\'' +
                ", detailMetodtype=" + detailMetodtype +
                ", detailDomainUrl='" + detailDomainUrl + '\'' +
                ", detailPageDivCss='" + detailPageDivCss + '\'' +
                '}';
    }
}
